#
# spec file for package goaccess
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2013 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global goaccess_services goaccess@.service goaccess@.timer

Name:           goaccess
Version:        1.9.3
Release:        1.2
Summary:        Apache Web Log Analyzer
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Web/Utilities
URL:            https://goaccess.io/
Source0:        http://tar.goaccess.io/goaccess-%{version}.tar.gz
Source10:       goaccess@.service
Source11:       goaccess@.timer
Source20:       README.SUSE.md
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  make
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig(libmaxminddb)
Recommends:     %{name}-lang

%description
GoAccess is an Apache web log analyzer that provides HTTP statistics
for system administrators that require a visual report on the fly.

%lang_package

%prep
%autosetup -p1
cp %{SOURCE20} .

%build
%configure \
    --enable-utf8 \
    --enable-geoip=mmdb

%make_build

%install
%make_install

install -d -m 0755 %{buildroot}%{_unitdir}
install -m 0644 %{SOURCE10} %{buildroot}%{_unitdir}/goaccess@.service
install -m 0644 %{SOURCE11} %{buildroot}%{_unitdir}/goaccess@.timer

%find_lang %{name}

%pre
%service_add_pre %{goaccess_services}

%post
%service_add_post %{goaccess_services}

%preun
%service_del_preun %{goaccess_services}

%postun
%service_del_postun %{goaccess_services}

%files -f %{name}.lang
%license COPYING
%doc AUTHORS ChangeLog NEWS README.md README.SUSE.md TODO
%{_bindir}/goaccess
%{_mandir}/man1/goaccess.1%{?ext_man}
%dir %{_sysconfdir}/goaccess/
%config %{_sysconfdir}/goaccess/browsers.list
%config %{_sysconfdir}/goaccess/goaccess.conf
%{_sysconfdir}/goaccess/podcast.list
%{_unitdir}/goaccess@.service
%{_unitdir}/goaccess@.timer

%changelog
* Mon Jun  3 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.9.3:
  * Added additional common bots to the list.
  * Added Address Sanitizer via '--enable-asan' to the configure
    options for debugging purposes.
  * Fixed inability to parse JSON keys containing dots.
  * Fixed out-of-bounds access for invalid HTTP status codes.
  * Fixed out-of-bounds access when parsing a log in serial processing mode.
  * Fixed regression introduced in 8f570c, which caused duplicate
    counts upon restoring from disk via '--restore'.
* Fri Apr 12 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.9.2:
  * Added World Map to the Geo Location panel on the HTML report.
  * Added additional non-official/standard HTTP status codes such
    as Caddy's 0 HTTP status among others.
  * Added support for '%%z' on strptime for non-glibc systems,
    such as musl libc in Alpine Linux (Docker container), enabling
    the use of '--tz'
  * Changed the '--hide/ignore-referrer' options to filter by
    hostname directly without the use of wildcards, e.g.,
    '--ignore-referrer=wiki.google.com'.
  * Fixed inability to parse duplicate specifiers during log format parsing.
  * Fixed regression which previously hindered the ability to
    modify log, date, and time formats within the TUI dialog.
    i.e., '# goaccess access.log -c'.
  * Replaced 'remote_ip' with 'client_ip' for Caddy's JSON format,
    allowing the use of trusted proxies.
  * Updated Caddy JSON example log format to handle headers correctly.
  * Updated Swedish i18n.
* Tue Feb  6 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.9.1:
  * Added support for macOS to the OS detection.
  * Fixed C99 mode issue with initial declarations [CentOS7].
  * Fixed minor typographical, orthographic, and grammatical errors
  in the German translation.
  * Fixed a regression issue wherein parsing would halt at the first
  empty log file.
* Wed Jan 31 2024 Michael Vetter <mvetter@suse.com>
- Updaet to 1.9:
  * Added multi-threaded log processing with '--jobs=<num>' for a boost
  in parsing speed, achieving an improvement ranging from 1.26 to 3.65x faster.
  * Added the 'SEARCH' method to the list of HTTP request methods.
  * Added compatibility to include the Traefik log format.
  * Added the ability to gracefully handle SIGQUIT as a signal for shutdown.
  * Altered WebSocket server initialization, ensuring it takes place after log-format checks.
  * Deprecated '--output-format'; now, only the '--output' option is permissible.
  * Implemented mutex locking to prevent a TZ environment race condition.
  * Fixed a potential heap overflow when checking a request for bots.
  * Fixed sorting of child items on HTML panels when sorting a column via the UI.
  * Fixed an issue where, in some cases, the referer host wouldn't be extracted properly
  * Fixed the miscategorization of Android 12.1 under operating systems.
  * Fixed TUI and temporarily ignored SIGINT during subdialog execution via Ctrl+C.
  * Updated the list of browsers/bots.
* Thu Nov  2 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.8.1:
  * Added latest Android and macOS versions to the list of OSs.
  * Fixed issue when trying to apply a regex on an invalid value
    (HTML report).
  * Fixed issue with D3.js xScale.domain() going out of boundaries
    in certain cases.
  * Prevent setting default static files when no static-file
    options are defined in config file.
* Sun Oct  1 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.8:
  * Added dual-stack support to the WebSocket server.
  * Added Debian Bookworm to the official deb repo.
  * Added Ubuntu Lunar to the official deb repo.
  * Fixed compiler error on macOS 10.12.
  * Updated bootstrap to v3.4.
  * Updated FontAwesome with additional icons for upcoming major release.
  * Updated Japanese translation.
  * Updated OS display from Macintosh to macOS.
  * Updated to D3.js v7 (latest) including charts.js code.
* Sat Apr  1 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.7.2:
  * Added a color-coding scheme to HTTP status codes.
  * Added '--external-assets' command line option to output external
    JS+CSS files. Great when used with Content Security Policy (CSP).
  * Ensure there's a fallback for 'Windows' if it appears on the user-agent.
  * Ensure we construct the WebSocket URL in a way that supports multiple
    use cases when used along '--ws-url' and '--port'.
  * Fixed a segfault due to a null pointer exception on FreeBSD.
  * Fixed build with '--disable-nls'.
  * Fixed invalid read (heap-buffer-overflow) when parsing an XFF spec via JSON.
  * Fixed segfault when parsing a specific XFF specifier.
* Wed Mar  1 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.7.1:
  * Added 'inlang' for easy localization (i18n) updates.
  * Added nanosecond parsing option via the '%%n' specifier.
    Great for parsing 'Traefik' JSON logs duration field.
  * Changed Docker workflow to build a docker image on different
    architectures {'arm64' & 'amd64'}.
  * Fixed issue with '--unknowns-as-crawlers' where it did not
    process them as such.
* Mon Jan  2 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.7:
  * Added an option to classify unknown OS and browsers as crawlers using
    `--unknowns-as-crawlers`.
  * Added highlighting to certain metrics on the HTML report for readability.
  * Added support ASN mapping for GeoIP2 and legacy databases.  Great for
    detecting malicious traffic and block accordingly.
  * Changed and prioritize user's browsers list over heuristics.
  * Fixed invalid read when loading the list of agents for an IP.
  * Fixed issue where a file containing a nul `\0` character would crash the
    program.
  * Updated Swedish i18n.
* Wed Nov  2 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.6.5:
  * Updated Dockerfile build stage to use alpine:3.
  * Updated deb build to use the right libncursesw6 dependency.
* Mon Oct  3 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.6.4:
  * Added Korean translation (i18n).
  * Added the ability to use filenames as virtualhosts using
    '--fname-as-vhost=<regex>'.
  * Enabled clawlers/bots under the OSs panel instead of being shown as
    'Unknown'.
  * Updated the format on the command-line help output.
* Fri Sep  2 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.6.3:
  * Enabled DNS thread when resolving a host and outputting real-time HTML.
    This helps avoid stalling the WS server on busy connections.
  * Fixed issue where it would not properly parse an XFF if the '%%h' specifier
    was already set.
  * Fixed possible XSS issues when using '--html-custom-css' and
    '--html-custom-js' by allowing valid filenames.
* Fri Jul 15 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.6.2:
  * Added `Android 12` to the list of OSs.
  * Added `macOS 12 Ventura` to the list of OSs.
  * Fixed implicit declaration build issue due to `timegm(3)` on `BSDs` and `macOS`.
  * Fixed issue where timezone conversion would be performed twice on a given
    date.
* Mon Jul  4 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.6.1:
  * Added a `--ping-interval=<secs>` in an attempt to keep the WebSocket
    connection opened.
  * Added support for timezone conversion via `--datetime-format=<format>` and
    `--tz=<timezone>`.
  * Added the ability to reconnect to WebSocket server after 1 sec with
    exponential backoff (x20).
  * Fixed issue where an invalid client connection would stall data out to
    clients via the WebSocket server.
  * Fixed issue where real-time data would be parsed multiple times under
    `Cygwin`.
* Wed Jun  1 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.6:
  * Changed slightly how the XFF field is specified. See man page for details.
  * Ensure city is displayed with the DBIP City Lite database.
  * Ensure no 'cleaning up resources' message  is displayed if `--no-progress`
    is passed.
  * Ensure the maximum number of items per panel defaults to 1440 (24hrs) when
    passing `--date-spec=min`.
  * Fixed issue when parsing a delimited XFF field followed by a host IP.
  * Fixed issue where some data was buffered on the WebSocket server before it
    was sent to each client.
  * Fixed issue where the WebSocket server would fail with POLLNVAL consuming
    100%% CPU.
  * Fixed segfault when attempting to open an unresolved IP on mac/BSDs.
* Fri Apr 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.5.7:
  * Updated Caddy's JSON format. This should address CADDY's v2.5.0 change.
  * Updated GeoIP module so it defaults to native language name (i18n) or
    fall-back to English.
  * Updated translations
* Fri Apr  1 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.5.6:
  * Added `--anonymize-level=<1|2|3>` option to specify IP anonymization level.
  * Added minute specificity to the Visitors panel via `--date-spec=min`.
  * Added the ability to toggle on/off panels on the HTML report.
  * Changed stderr to stdout on non-error output when exiting goaccess.
* Tue Feb  1 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.5.5:
  * Added mechanism to automatically parse additional bots.
  * Changed area chart interpolation to 'monotone'. This should avoid the issue
  * the interpolated curve has a bend into the negative space.
  * Changed build to use debugging symbols even for release builds.
  * Changed order on which we verify bots to be the first thing we check. This
  * a slight improvement on parsing time.
  * Ensure we initialize DNS resolver conditions and mutexes before they're used.
  * Fixed possible buffer over-read for cases where a '\0' could be reached
  * when parsing a log line.
  * Fixed possible data race on UI spinner thread.
  * Fixed regression where a lot of robots where not detected by GoAccess.
* Tue Jan  4 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.5.4:
  * Added AWS ALB to the predefined logs format list --log-format=AWSALB.
  * Ensure we lock our pipe/websocket writer before broadcasting message.
  * Ensure we require a valid host token even when we're not validating the IP.
  * Ensure we simply update the TUI once after tailing multiple files.
  * Ensure we simply update the UI once after tailing multiple files.
  * Fixed buffer overflow when checking if an HTTP code was a 404 on an empty
    code.
  * Optimized terminal and HTML UI output when tailing multiple files.
  * Updated DB PATH error message to be more descriptive.
* Mon Dec  6 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.5.3:
  * Added additional crawlers to the default list.
  * Added Italian translation (i18n).
  * Added 'macOS 12' to the list of OS.
  * Fixed buffer overflow caused by an excessive number of invalid
    requests with multiple logs.
  * Fixed visualization issue on the HTML report for panels with
    disabled chart.
* Thu Nov 11 2021 Andreas Schneider <asn@cryptomilk.org>
- Fix systemd target for the timer which ends up with cylces otherwise
  basic.target: Found ordering cycle on goaccess@foobar.timer/start
  basic.target: Found dependency on time-sync.target/start
  basic.target: Found dependency on chronyd.service/start
  basic.target: Found dependency on network.target/start
  basic.target: Found dependency on wickedd-nanny.service/start
  basic.target: Found dependency on basic.target/start
  basic.target: Job goaccess@foobar.timer/start deleted to break ordering cycle starting with basic.target/start
* Thu Sep 30 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.5.2:
  * Added .avi to the list of static requests/extensions.
  * Changed label from 'Init. Proc. Time' to 'Log Parsing Time'.
  * Fixed issue where lengthy static-file extension wouldn't account certain
    valid requests.
  * Fixed possible buffer underflow when checking static-file extension.
  * Fixed segfault when attempting to parse an invalid JSON log while using a
    JSON log format.
  * Fixed segfault when ignoring a status code and processing a line > '4096'
    chars.
* Mon Jul  5 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.5.1:
  - Changed official deb repo so it now builds '--with-getline' in order to
    support request lines longer than 4096.
  - Ensure there's no tail delay if the log file hasn't changed.
  - Fixed data race when writing to a self-pipe and attempting to stop the WS server.
  - Fixed inability to close expanded panel when pressing 'q' on TUI.
  - Fixed possible data race during parsing spinner label assignment.
  - Increased the maximum number of files to monitor from '512' to '3072'.
* Thu May 27 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.5:
  * Added a Docker container based isolated build environment (Debian).
  * Added Dark Mode detection to the HTML report.
  * Added the ability for the WebSocket server to bind to a Unix-domain socket.
  * Added the ability to parse IPs enclosed within brackets (e.g., IPv6).
  * Changed categorization of requests containing 'CFNetwork' to 'iOS' when
    applicable.
  * Changed command line option from '--hide-referer' to '--hide-referrer'.
  * Changed command line option from '--ignore-referer' to '--ignore-referrer'.
  * Fixed a potential division by zero.
  * Fixed inablity to parse IPv6 when using a 'CADDY' log format.
  * Fixed issue where a 'BSD' OS could be displayed as Linux with certain
    user-agents.
  * Fixed memory leak when a JSON value contained an empty string (e.g.,
    JSON/CADDY format).
  * Fixed possible buffer overflow on a WS packet coming from the browser.
  * Refactored a substancial part of the storage codebase for upcoming
    filtering/search capabilities (issue #117).
  * Refactored DB storage to minimize memory consumption up to '35%%'.
  * Updated default 'AWS Elastic Load Balancing' log format.
  * Updated German translation.
  * Updated page size to 24 on the HTML report.
  * Updated UNIX OS catergories.
* Mon Mar  1 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.4.6:
  * Added additional feed reader clients.
  * Added addtional browsers and bots to the main list.
  * Added command line option '--unknowns-log' to log unknown browsers and
    OSs.
  * Added 'Referer' to the pre-defined 'Caddy JSON' log format.
  * Added support for real-time piping as non-root user.
  * Added the ability to Handle case when IPv4 is encoded as IPv6 in
    GeoIP1/legacy.
  * Ensure we capture linux (lowercase) when extracting an OS.
  * Fixed a regression in parsing Google Cloud Storage or possibly other
    non-JSON formats.
  * Fixed inability to parse escaped formats.
  * Fixed issue when using '%%s' with 'strptime(3)' under musl libc. This
    addresses mostly the Docker image.
  * Fixed possible buffer over-read for certain log-format patterns.
  * Fixed segfault when attempting to process a malformed JSON string.
  * Fixed segfault when setting an empty log-format from the TUI dialog.
  * Fixed sorting on hits and visitors when larger than INT_MAX.
  * Updated CloudFront pre-defined log-format to reflect the latest fields.
  * Updated 'Dockerfile' image to use 'alpine:3.13' instead of edge due to
    compatibility issue with the GNU coreutils.
* Mon Mar  1 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.4.5:
  * Fixed build issue due to initial declarations only allowed in C99 mode
* Mon Jan 25 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.4.4:
  * Added 'Caddy' to the list of pre-defined log formats.
  * Added command line option '--no-strict-status' to disable status validation.
  * Added native support to parse JSON logs.
  * Added the ability to process timestamps in milliseconds using '%%*'.
  * Ensure TUI/CSV/HTML reports are able to output 'uint64_t' data.
  * Ensure we allow UI render if the rate at which data is being read is
  * than '8192' req/s.
  * Ensure we don't re-render Term/HTML output if no data was read/piped.
  * Fixed build configure to work on NetBSD.
  * Fixed issue where it would send data via socket each second when managed
  * systemd.
  * Fixed issue where parser was unable to parse syslog date with padding.
  * Fixed issue where some items under browsers.list were not tab separated.
  * Fixed issue where the format parser was unable to properly parse logs
  * by a pipe.
  * Fixed issue where T.X. Amount metrics were not shown when data was piped.
  * Fixed issue where XFF parser could swallow an additional field.
  * Fixed memory leak when using '%%x' as date/time specifier.
  * Replaced select(2) with poll(2) as it is more efficient and a lot faster
  * select(2).
  * Updated Swedish i18n.
* Mon Jan  4 2021 Andreas Schneider <asn@cryptomilk.org>
- Fix starting the timer on boot
* Mon Dec 28 2020 Andreas Schneider <asn@cryptomilk.org>
- Enable geoip support
- Added systemd service files
- Added README.SUSE.md
* Fri Dec  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.3:
  * Added the ability to set how often goaccess will parse data and output to
    the HTML report via '--html-refresh=<secs>'.
  * Changed how TLS is parsed so the Cypher uses a separate specifier.
    It now uses '%%K' for the TLS version and '%%k' for the Cypher.
  * Fixed issue where real-time output would double count a rotated log. This
    was due to the change of inode upon rotating the log.
  * Updated man page to reflect proper way of 'tail -f' a remote access log.
* Mon Nov 16 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.2:
  * Added the ability to show 'Encryption Settings' such as ' TLSv1.2' and
    Cipher Suites on its own panel.
  * Added the ability to show 'MIME Types' such as ' application/javascript' on
    its own panel.
  * Changed Debian build to use mmdb instead of libgeoip (legacy).
  * Ensure the HTML report defaults to widescreen if viewport is larger than
    '2560'.
  * Fixed inability to properly process multiple logs in real-time.
  * Fixed issue where named PIPEs were not properly seed upon generating
    filename.
  * Fixed issue where served time metrics were not shown when data was piped.
  * Removed unnecessary padding from SVG charts. Improves readability on mobile.
* Mon Nov  9 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.1:
  * Added addtional browsers and bots to the main list.
  * Added 'Android 11' to the list of OSs.
  * Added 'macOS 11.0 Big Sur' to the list of OSs.
  * Added 'average' to each panel overall metrics.
  * Added '.dmg', '.xz', and '.zst' to the static list.
  * Added extra check to ensure restoring from disk verifies the content of the
  * against previous runs.
  * Added Russian translation (i18n).
  * Added Ukrainian translation (i18n).
  * Added support for HTTP status code '308'.
  * Added the ability for 'get_home ()' to return NULL on error, instead of
  * the process. Great if using through systemd.
  * Added the ability to read lowercase predefined log formats. For instance,
  * log-format=COMBINED' or '--log-format=combined'.
  * Changed how FIFOs are created and avoid using predictable filenames under
    tmp'.
  * Changed '--ignore-referer' to use whole referrer instead of referring site.
  * Ensure Cache Status can be parsed without sensitivity to case.
  * Ensure restored data enforces '--keep-last' if used by truncating accordingly
  * Fixed a few memory leaks when restoring from disk.
  * Fixed blank time distribution panel when using timestamps.
  * Fixed build issue due to lack of 'mmap' on 'Win'/'Cygwin'/'MinGW'.
  * Fixed crash in mouse enabled mode.
  * Fixed double free on data restore.
  * Fixed inability to keep processing a log when using '--keep-last'.
  * Fixed inability to properly parse truncated logs.
  * Fixed inability to properly count certain requests when restoring from disk
  * Fixed issue where it would not parse subsequent requests coming from stdin (tail).
  * Fixed issue where log truncation could prevent accurate number counting.
  * Fixed issue where parsed date range was not rendered with '--date-spec'.
  * Fixed issue where parser would stop regardless of a valid '--num-test' value.
  * Fixed issue where restoring from disk would increment 'MAX.TS'.
  * Fixed possible incremental issue when log rotation occurs.
  * Fixed possible XSS when getting real-time data into the HTML report.
  * Fixed potential memory leak when failing to get root node.
  * Fixed real-time hits count issue for certain scenarios.
  * Fixed segfault in 'Docker' due to a bad allocation when generating FIFOs.
  * Fixed 'Unknown' Operating Systems with 'W3C' format.
  * Removed unnecessary include from parser.c so it builds in macOS.
  * Updated each panel overall UI to be more streamlined.
  * Updated French translation.
  * Updated German translation.
  * Updated Spanish translation.
  * Updated sigsegv handler.
* Mon May 18 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4:
  * Added a caching storage mechanism to improve parsing raw data and data
    rendering.
  * Added a mechanism to avoid counting duplicate data when restoring persisted
    data from disk.
  * Added additional option to the HTML report to set a maximum number of items
    per page to 3.
  * Added a list of podcast-related user agents under '%%sysconfdir%%'.
  * Added 'Android 10' to the list of Android codenames.
  * Added a 'widescreen' layout to the HTML report (e.g., 4K TV/KPI Dashboard).
  * Added 'Beaker', 'Brave', and 'Firefox Focus' to the list of browsers
  * Added command line option --user-name=username to avoid running GoAccess as
    root when outputting a real-time report.
  * Added 'DuckDuckGo' and 'MSNBot' browsers to the browsers.list.
  * Added 'facebookexternalhit' to the default crawler list.
  * Added German translation (DE).
  * Added Kubernetes Nginx Ingress Log Format to the default config file.
  * Added 'macOS Catalina' to the list of OSX codenames.
  * Added minor CSS updates to HTML report.
  * Added missing header '<sys/socket.h>' to fix FreeBSD build
  * Added new 'Edg' token to the list of browsers.
  * Added '--no-ip-validation' command line to disable client IP validation
  * Added '--persist' and '--restore' options to persist to disk and restore a
    dump from disk.
  * Added Portuguese translation (pt-BR)
  * Added Swedish translation (SV)
  * Added the ability to parse server cache status and a new panel to display
    those metrics.
  * Changed accumulated time to work by default on '--persist' and '--restore'.
  * Changed back how the hits and visitors percentage is calculated to be more
    intuitive.
  * Changed Geo Location panel display default to show only if database file is
    provided ('LIBMAXMINDDB').
  * Changed initial processing time from secs to HH:MM:SS in HTML output.
  * Changed '--max-items' for the static HTML report to allow no limit on
    output entries.
  * Changed required 'gettext' version to 0.19
  * Changed to ignore 'SIGPIPE' with 'SIG_IGN'
  * Changed version to 10.15 for 'macOS Catalina'.
  * Ensure proper escaping on default AWSELB log format.
  * Ensure valid requests counter is not affected on duplicate entries when
    restoring data.
  * Fixed issue preventing Ctrl-C (SIGINT) for the curses interface to stop the
    program.
  * Fixed issue where HTML report wouldn't update the tables when changing per
    page option.
  * Fixed issue where it wouldn't find either the user's or global config file.
  * Fixed issue where changing the number of items per page in the HTML report
    would not automatically refresh the tables.
  * Fixed issue where last updated label was not updated in real-time.
  * Fixed issue where overall date range wasn't showing the right start/end parse
    dates.
  * Fixed issue where tailing a file could potentially re-parse part of the log.
  * Fixed memory leak when fetching country/continent while using 'LIBMAXMINDDB'.
  * Fixed several '-Wcast-qual' warnings.
  * Fixed unwanted added characters to the HTML output.
  * Fixed websocket issue returning a 400 due to request header size.
  * Increased 'MAX_LINE_CONF' so a JSON string can be properly parsed from the
    config file.
  * Removed deprecated option '--geoip-city-data' from config file.
  * Removed unnecessary dependency from snapcraft.yaml.
  * Removed Vagrantfile per #1410
  * Removed some old browsers from the default curated list.
  * Replaced TokyoCabinet storage for a non-dependency in-memory persistent
    storage.
  * Updated Dockerfile.
- Remove bin2c.patch: upstreamed
- Build without --enable-geoip flag
* Mon Mar  9 2020 pgajdos@suse.com
- build with libmaxminddb [bsc#1156207]
* Mon Aug 26 2019 Hendrik Vogelsang <hvogel@suse.com>
- Add bin2c.patch to fix
  https://github.com/allinurl/goaccess/issues/1415
  which lead to garbage in HTML reports
* Fri Nov 23 2018 mvetter@suse.com
- Update to 1.3
  * Added ability to store accumulated processing time into DB_GEN_STATS tcb
    file via '--accumulated-time' command line option.
  * Added additional Apache status codes to the list.
  * Added a few feed readers to the list.
  * Added more OSs to the list of OSs.
  * Added --anonymize-ip command line option to anonymize ip addresses.
  * Added --browsers-file command line option to load a list of crawlers from a
    text file.
  * Added byte unit (PiB) to formatters
  * Added translations
  * Added '%%h' date specifier to the allowed date character specifiers.
  * Added "HeadlessChrome" to the list of browsers.
  * Added --hide-referer command line option to hide referers from report.
  * Added HTTP status code 429 (TOO MANY REQUESTS).
  * Added IGNORE_LEVEL_PANEL and IGNORE_LEVEL_REQ definitions.
  * Added --ignore-referer-report command line option to hide referers from
    output.
  * Added "Mastodon" user-agent to the list of crawlers/unix-like.
  * Added new fontawesome icons and use angle arrows in HTML paging.
  * Added new purple theme to HTML report and default to it.
  * Added --no-parsing-spinner command line option to switch off parsing
    spinner.
  * Added .ogv and ogg static file extension (ogg video, Ogg Vorbis audio).
  * Added OS X version numbers when outputting with --real-os.
  * Added parsing mechanism in an attempt capture more bots and to include
    unspecified bots/crawlers.
  * Added --pidfile command line option to the default config file.
  * Added SSL support for Docker goaccess build.
  * Added support to the WebSocket server for openssl-1.1*.
  * Added the ability to show/hide a chart per panel in the HTML report.
  * Added transparency to the navigation bar of the HTML report.
  * Added "WhatsApp" user-agent to the list of crawlers.
  * Changed default db folder so it adds the process id (PID). --db-path is
    required now when using --load-from-disk.
  * Changed Dockerfile to build from the current source.
  * Changed 'hits' to be right-aligned on TUI.
  * Changed to use faster slide animations on HTML report.
  * Changed wording from 'Bandwidth' to the proper term 'Tx. Amount'.
  * Ensure database filenames used by btree are less predictable.
  * Ensure HTML templates, CSS and JS files are minified when outputting
    report.
  * Ensure key phrases from Google are added even when https is used.
  * Ensure live report updates data & charts if tab/document has focus.
  * Ensure multiple 'Yandex' crawlers are properly parsed.
  * Ensure Safari has priority over most crawlers except the ones that are
    known to have it.
  * Ensure the request protocol on its own is properly parsed.
  * Ensure the right number of tests are performed against the given log.
  * Ensure user configuration is parsed first when available.
  * Ensure wss:// is used when connecting via HTTPS.
  * Ensure XFF parser takes into account escaped braces.
  * Fixed a regression where fifo-in/out would fail with ENXIO.
  * Fixed a regression where it would return EXIT_FAILURE on an empty log.
  * Fixed a (ssh) pipeline problem with fgetline()/fgets() when there is a race
    for data on stdin.
  * Fixed broken X-Forwarded-For (XFF) %%~ specifier in certain parsing cases.
  * Fixed conf.filenames duplication problem if logs are via pipe.
  * Fixed float percent value on JSON/HTML output for locales using decimal comma.
  * Fixed issue where it was not possible to establish a Web Socket connection
    when attempting to parse and extract HTTP method.
  * Fixed issue where log formats with pipe delimiter were not propely parsed.
  * Fixed memory leak after config file path has been set (housekeeping).
  * Fixed memory leak when adding host to holder introduced in c052d1ea.
  * Fixed possible memory leak when hiding specific referrers.
  * Fixed several JS jshint warnings.
  * Fixed sudo installs on TravisCI.
  * Fixed UNDEFINED time range in HTML report when VISITORS panel was ignored.
  * Fixed unnecessary closing span tags from template.
  * Fixed use-after-free when two color items were found on color_list.
- Add language package
* Thu Oct 18 2018 Jan Engelhardt <jengelh@inai.de>
- Remove filler wording from description.
* Thu Oct 18 2018 mvetter@suse.com
- Use %%license instead of %%doc
* Tue Oct  9 2018 mvetter@suse.com
- Remove wrongly added v1.2.tar.gz
* Tue Jan 16 2018 mvetter@suse.com
- Clean up spec file
- Update to 1.2:
  * Added a Dockerfile.
  * Added a replacement for GNU getline() to dynamically expand line buffer
    while  maintaining real-time output.
  * Added --daemonize command line option to run GoAccess as daemon.
  * Added several improvements to the HTML report on small-screen devices.
  * Added option to the HTML report to auto-hide tables on small-screen
  * Added --process-and-exit command line option to parse log and exit.
  * Added several feed readers to the list of browsers.
  * Added "-" single dash per convention to read from the standard input.
  * Added support for MaxMind GeoIP2.
  * Added the ability to read and follow from a pipe such as
    "tail -f access.log | goaccess -"
  * Added time unit (seconds) to the processed time label in the HTML/terminal
  * Added visitors' percent column to the terminal dashboard.
  * Changed D3 charts to dim Y-axis on mouseover.
  * Changed D3 charts to reflect HTML column sort.
  * Changed D3 charts to render only if within the viewport. This improves the
    real-time HTML performance.
  * Changed HTML report tables to render only if within the viewport.
  * Changed percentage calculation to be based on the total within each panel.
  * Ensure start/end dates are updated real-time in the HTML output.
  * Ensure "window.location.hostname" is used as the default WS server host.
  * most cases, this should avoid the need for specifying "--ws-url=host".
  * using "--real-time-html" should suffice.
  * Fixed issue on HTML report to avoid outputting scientific notation for all
  * sizes.
  * Fixed integer overflow when calculating bar graph length on terminal.
  * Fixed issue where global config file would override command line arguments.
  * Fixed issue where it wouldn't allow loading from disk without specifying a
  * when executed from the cron.
  * Fixed issue where parser couldn't read some X-Forwarded-For (XFF) formats.
    that this breaks compatibility with the original implementation of
    XFF, but at the same time it gives much more flexibility on different.
  * Fixed issue where specifying fifo-in/out wouldn't allow HTML real-time
  * Fixed issue where the wrong number of parsed lines upon erroring out was
  * Fixed issue where the WebSocket server prevented to establish a connection
    a client due to invalid UTF-8 sequences.
  * Fixed percent issue when calculating visitors field.
  * Updated the list of crawlers.
* Wed May  6 2015 mrueckert@suse.de
- update to 0.9
  * Added ability to double decode an HTTP referer and agent.
  * Added ability to sort views through the command line on initial load.
  * Added additional data values to the backtrace report.
  * Added additional graph to represent the visitors metric on the HTML output.
  * Added AM_PROG_CC_C_O to configure.ac
  * Added 'Android Lollipop' to the list of operating systems.
  * Added 'average time served' metric to all panels.
  * Added 'bandwidth' metric to all panels.
  * Added command line option to disable summary metrics on the CSV output.
  * Added numeric formatting to the HTML output to improve readability.
  * Added request method specifier to the default W3C log format.
  * Added support for GeoIP Country IPv6 and GeoIP City IPv6 through --geoip-database.
  * Added the ability to ignore parsing and displaying given panel(s).
  * Added the ability to ignore referer sites from being counted.
    A good case scenario is to ignore own domains. i.e., owndomain.tld
    This also allows ignoring hosts using wildcards.
    For instance, *.mydomain.tld or www.mydomain.* or www?.mydomain.tld
  * Added time/hour distribution module. e.g., 00-23.
  * Added 'visitors' metrics to all panels.
  * Added Windows 10 (v6.4) to the real windows user agents.
  * Changed AC_PREREQ macro version so it builds on old versions of autoconf.
  * Changed GEOIP database load to GEOIP_MEMORY_CACHE for faster lookups.
  * Changed maximum number of choices to display per panel to 366 fron 300.
  * Ensure config file is read from home dir if unable to open it from %%sysconfdir%% path.
  * Fixed array overflows when exceeding MAX_* limits on command line options.
  * Fixed a SEGFAULT where sscanf could not handle special chars within the referer.
  * Fixed character encoding on geolocation output (ISO-8859 to UTF8).
  * Fixed issue on wild cards containing '?' at the end of the string.
  * Fixed issue where a 'Nothing valid to process' error was triggered when the
    number of invalid hits was equal to the number of valid hits.
  * Fixed issue where outputting to a file left a zero-byte file in pwd.
  * Improved parsing of operating systems.
  * Refactored log parser so it allows with ease the addition of new modules. This
    also attempts to decouple the core functionality from the rendering functions.
    It also gives the flexibility to add children metrics to root metrics for any
    module. e.g., Request A was visited by IP1, IP2, IP3, etc.
  * Restyled HTML output.
* Fri Oct 31 2014 wagner-thomas@gmx.at
- Changes to GoAccess 0.8.5 - Sunday, September 14, 2014
  * Fixed SEGFAULT when parsing a malformed request that doesn't have HTTP status.
- Changes to GoAccess 0.8.4 - Monday, September 08, 2014
  * Added ability to handle nginx non-standard status code 444 as 404.
    `--444-as-404`
  * Added and updated operating systems, and browsers.
  * Added excluded IP hits count to the general statistics panel on all reports.
  * Added HTTP nonstandard code '444' to the status code list.
  * Added the ability to count client errors (4xx) to the unique visitors count.
    Now by default it omits client errors (4xx) from being added to the unique
    visitors count as they are probably not welcomed visitors. 4xx errors are
    always counted in panels other than visitors, OS & browsers.
    `--4xx-to-unique-count`
  * Removed request status field restriction. This allows parsing logs that contain
    only a valid date, IPv4/6 and host.
  * Fixed issue when excluding IPv4/v6 ranges.
  * Fixed compile error due to missing include <sys/types.h> for type off_t
    (gcc 4.1).
- Changes to GoAccess 0.8.3 - Monday, July 28, 2014
  * Fixed SEGFAULT when parsing a CLF log format and using --ignore-crawlers.
  * Fixed parsing conflict between some Opera browsers and Chrome.
  * Fixed parsing of several feed readers that are Firefox/Safari-based.
  * Fixed Steam detection.
  * Added Huawei to the browser's list and removed it from the OS's list.
- Changes to GoAccess 0.8.2 - Monday, July 20, 2014
  * Added ability to parse dates containing whitespaces in between,
    e.g., Jul 15 20:13:59 (syslog format).
  * Added a variety of browsers, game systems, feed readers, and podcasts.
  * Added a '-V --version' command line option.
  * Added missing up/down arrows to the help section.
  * Added the ability to ignore crawlers using the '--ignore-crawlers' option.
  * Added the ability to ignore multiple IPv4/v6 and IP ranges.
  * Added the PATCH method according to RFC 5789.
  * Fixed GeoLocation percent issue for the JSON, CSV and HTML outputs.
  * Fixed memory leak when excluding one or multiple IPs.
- Changes to GoAccess 0.8.1 - Monday, June 16, 2014
  * Added ability to add/remove static files by extension through the config
    file.
  * Added ability to print backtrace on segmentation fault.
  * Escaped JSON strings correctly according to [RFC4627].
  * Fixed encoding issue when extracting keyphrases for some HTTP referers.
  * Fixed issue where HTML bar graphs were not shown due to numeric locale.
  * Fixed issue with URIs containing "\r?\n" thus breaking the corresponding
    output.
  * Make sure request string is URL decoded on all outputs.
- Changes to GoAccess 0.8 - Tuesday, May 20, 2014
  * Added APT-HTTP to the list of browsers.
  * Added data persistence and ability to load data from disk.
  * Added IE11 to the list of browsers.
  * Added IEMobile to the list of browsers.
  * Added multiple command line options.
  * Added Nagios check_http to the list of browsers.
  * Added parsing progress metrics - total requests / requests per second.
  * Added the ability to parse a GeoLiteCity.dat to get the city given an IPv4.
  * Change the way the configuration file is parsed. This will parse all
    configuration options under ~/.goaccessrc or the specified config file and will
    feed getopt_long with the extracted key/value pairs. This also allows the
    ability to have comments on the config file which won't be overwritten.
  * Ensure autoconf determines the location of ncurses headers.
  * Fixed issue where geo_location_data was NULL.
  * Fixed issue where GoAccess did not run without a tty allocated to it.
  * Fixed potential memory leak on --log-file realpath().
  * Fixed Solaris build errors.
  * Implemented an on-memory hash database using Tokyo Cabinet. This implementation
    allows GoAccess not to rely on GLib's hash table if one is needed.
  * Implemented large file support using an on-disk B+ Tree database. This
    implementation allows GoAccess not to hold everything in memory but instead it
    uses an on-disk B+ Tree database.
  * Trimmed leading and trailing whitespaces from keyphrases module.
- Changes to GoAccess 0.7.1 - Monday, February 17, 2014
  * Added ability to get real OS names using --real-os. (Android, Windows, Mac)
  * Added ability to log debug messages to a file.
  * Added ability to parse tab-separated log format strings.
  * Added ability to support terminals without colors.
  * Added ability to turn off color output by using --no-color flag.
  * Added command line option to append HTTP method to request.
  * Added command line option to append HTTP protocol to request.
  * Added long options to command-line.
  * Added missing Win 9x 4.90 (Windows Me) user-agent.
  * Added missing Windows RT user-agent.
  * Ensure mouse click does not reset expanded module if it is the same.
  * Fixed Amazon CloudFront tab-separated log format.
  * Fixed "FreeBSD style" ncursesw built into system.
  * Fixed HTML report issue where data cell would not wrap.
  * Fixed issue when isatty() could not find a valid file descriptor.
  * Fixed SymbianOS user-agent and retrieve its version.
* Fri Jan  3 2014 pascal.bleser@opensuse.org
- update to 0.7:
  * added a command line option to ignore request query strings
  * added additional static file extensions
  * added country per IP to HOSTS module (HTML & JSON)
  * added GEOLOCATION report to all outputs - includes continents/countries
  * added IP resolver to HTML and JSON output
  * added module numbers to each module header
  * added the ability to output JSON and CSV
  * fixed buffer overflow issue with realpath
  * new HTML report - HTML5 + CSS styles
  * properly split request line into the three request modules
* Mon Jul 15 2013 pascal.bleser@opensuse.org
- update to 0.6:
  * adds an expandable dashboard, allowing data to be processed in realtime
  * ability to search across the whole dashboard, with the option to use
    regular expressions
  * active modules can now be sorted by multiple fields
  * parses the time taken to serve the request, in microseconds and seconds
  * other features and fixes have been added, as well
* Wed Nov 14 2012 suse@ammler.ch
- update to 0.5
  * Added the ability to parse a custom format string.
  * Added ability to output a full stats report to a file.
  * Added support for IPv6
  * Fixed issue on Opera agents where version was not recognized correctly.
  * Fixed issue on empty Google query strings.
  * Fixed google cache key-phrases.
  * Added a new include sys/socket.h - BSD
  * Added a key shortcut to scroll top/bottom.
  * Fixed other minor fixes and changes.
- removed patches (don't apply anymore)
- add sed to replace __DATE__ and __TIME
* Mon Jan  3 2011 pascal.bleser@opensuse.org
- update to 0.4.2:
  * UTF-8 support has been implemented
  * wide-character/UTF-8 is handled properly
  * -lrt has been removed
  * a minor bug when adding monthly totals was fixed
- changes from 0.4.1:
  * more flexibility when resizing the terminal; should work fine with the standard 80x24
  * implemented a pipeline from stdin, so the input doesn't have to be only a file
* Tue Nov 30 2010 pascal.bleser@opensuse.org
- update to 0.4:
  * glib 2.0 or later is now required instead of 2.16, as in previous versions
  * implemented list of agents for specific hosts
  * added graphs to the unique_visitors subwin
  * various bug fixes and code cleanups (mainly in the subwin modules)
  * bandwidth per day, and host was implemented as well
* Tue Sep 28 2010 pascal.bleser@opensuse.org
- add patch to use getaddrinfo
- update to 0.33:
  * a request size parsing issue was fixed: due to malformed syntax on the HTTP protocol, bandwidth was reset to 0
* Fri Sep 10 2010 pascal.bleser@opensuse.org
- update to 0.32:
  * fixes an agent parsing issue; as a result, operating systems are now properly counted
- changes from 0.31:
  * due to the difference of gamma correction on some monitors, a color scheme implementation was added
* Mon Aug 30 2010 pascal.bleser@opensuse.org
- update to 0.3:
  * a more detailed and comprehensive browser/OS report is produced
  * real support was added for LFS (files larger than 2 GiB on 32-bit systems)
  * bandwidth details were added for requested files
  * other features and bugfixes were made
* Mon Jul 26 2010 pascal.bleser@opensuse.org
- update to 0.2:
  * Real-time statistics (RTS) were implemented: data will be appended as the log file grows; this is similar to the use of "tail -f" on Unix systems
  * a keyphrases report coming from the Google search engine was added -- this includes, raw, cache, and translation queries
  * the screen resize functionality was implemented
  * several fixes and improvements were made
* Tue Jul 13 2010 pascal.bleser@opensuse.org
- update to 0.12:
  * fixes a segmentation fault when parsing logs with unusual request type
* Thu Jul  8 2010 pascal.bleser@opensuse.org
- initial package (0.1)
